aboutsummaryrefslogtreecommitdiffstats
path: root/src/cg-negative.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/cg-negative.c')
-rw-r--r--src/cg-negative.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/cg-negative.c b/src/cg-negative.c
index 106c15c..73f7e8c 100644
--- a/src/cg-negative.c
+++ b/src/cg-negative.c
@@ -144,20 +144,20 @@ int handle_opt(char* opt, char* arg)
* @param argv `NULL` terminated list of unparsed arguments
* @param method The argument associated with the "-M" option
* @param site The argument associated with the "-S" option
* @param crtcs The arguments associated with the "-c" options, `NULL`-terminated
* @param prio The argument associated with the "-p" option
* @param rule The argument associated with the "-R" option
* @return Zero on success, -1 on error
*/
int handle_args(int argc, char* argv[], char* method, char* site,
- char** crtcs, char* prio, char* rule)
+ char** crtcs_, char* prio, char* rule)
{
int q = xflag + (dflag | rplus | gplus | bplus);
q += (method != NULL) && !strcmp(method, "?");
q += (prio != NULL) && !strcmp(prio, "?");
q += (rule != NULL) && (!strcmp(rule, "?") || !strcmp(rule, "??"));
- for (; *crtcs; crtcs++)
- q += !strcmp(*crtcs, "?");
+ for (; *crtcs_; crtcs_++)
+ q += !strcmp(*crtcs_, "?");
if (argc || (q > 1) || (xflag && (prio != NULL)))
usage();
return 0;
@@ -144,20 +144,20 @@ int handle_opt(char* opt, char* arg)
* @param method The argument associated with the "-M" option
* @param site The argument associated with the "-S" option
- * @param crtcs The arguments associated with the "-c" options, `NULL`-terminated
+ * @param crtcs_ The arguments associated with the "-c" options, `NULL`-terminated
* @param prio The argument associated with the "-p" option
* @param rule The argument associated with the "-R" option